"use strict";

exports.__esModule = true;
exports.extractTimeseriesSeries = extractTimeseriesSeries;
exports.formatSeriesName = formatSeriesName;
exports.extractGroupbyLabel = extractGroupbyLabel;

var _constants = require("../constants");

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function extractTimeseriesSeries(data) {
  if (data.length === 0) return [];
  const rows = data.map(datum => _extends({}, datum, {
    __timestamp: datum.__timestamp || datum.__timestamp === 0 ? new Date(datum.__timestamp) : null
  }));
  return Object.keys(rows[0]).filter(key => key !== '__timestamp').map(key => ({
    name: key,
    // @ts-ignore
    // eslint-disable-next-line @typescript-eslint/no-unsafe-return
    data: rows.map(datum => [datum.__timestamp, datum[key]])
  }));
}

function formatSeriesName(name, {
  numberFormatter,
  timeFormatter
} = {}) {
  if (name === undefined || name === null) {
    return _constants.NULL_STRING;
  }

  if (typeof name === 'number') {
    return numberFormatter ? numberFormatter(name) : name.toString();
  }

  if (typeof name === 'boolean') {
    return name.toString();
  }

  if (name instanceof Date) {
    return timeFormatter ? timeFormatter(name) : name.toISOString();
  }

  return name;
}

function extractGroupbyLabel({
  datum,
  groupby,
  numberFormatter,
  timeFormatter
}) {
  return groupby.map(val => formatSeriesName(datum[val], {
    numberFormatter,
    timeFormatter
  })).join(', ');
}